# Asciicut

Simple CLI for trimming [asciinema](https://asciinema.org/) [`.cast`](https://docs.asciinema.org/manual/asciicast/v2/) files.

## Installation

Prefer to install using `pipx`:

```
pipx install asciicut
```
